#!/usr/bin/env bash
#
# Licensed Materials - Property of IBM
#
# IBM Financial Crimes Insight with Watson PID 5900-A0H
# IBM Financial Crimes Insight with Watson, Private PID 5737-E41
#
# (C) Copyright IBM Corp. 2017, 2018, 2019  All rights reserved.
#
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U. S. Copyright Office.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#

connect_to_cluster() {
	local -r cluster_name="${1}"; shift

	ibmcloud cs init && \
	ibmcloud cs cluster-config "${cluster_name}"
	rc=$?

	if [[ $rc == 0 ]]; then
		local -r location=$(ibmcloud cs cluster-get "$cluster_name" | grep ^Location: | awk '{print $2}')
		export KUBECONFIG="${HOME}/.bluemix/plugins/container-service/clusters/${cluster_name}/kube-config-${location}-${cluster_name}.yml"
	fi

	return $?
}

cloud_is_location_valid() {
	local rc=0
	local -r location="${1}"; shift

	if [[ $location != "" ]]; then
		if ! ibmcloud cs locations | grep -q "$location"; then
			rc=2
			echo "Location $location is invalid."
		fi
	else
		rc=1
		echo "No location specified"
	fi

	if [[ $rc != 0 ]]; then
		echo "Valid locations:"
		ibmcloud cs locations
	fi
	return $rc
}

cloud_is_machine_type_valid() {
	local rc=0
	local -r location="${1}"; shift
	local -r machine_type="${1}"; shift

	if [[ $machine_type != "" ]]; then
		if ! ibmcloud cs machine-types "$location" | grep -q "$machine_type"; then
			rc=4
			echo "Machine type $machine_type is invalid."
		fi
	else
		rc=3
	fi
	if [[ $rc != 0 ]]; then
		echo "Valid machine types:"
		ibmcloud cs machine-types "$location"
	fi

	return $rc
}

cloud_is_vlan_valid() {
	local rc=0
	local -r location="${1}"; shift
	local -r type="${1}"; shift
	local -r vlan="${1}"; shift

	if [[ $type != "" ]]; then
		if [[ $vlan != "" ]]; then
			if ! ibmcloud cs vlans --zone "$location"| grep "$type" | grep -q "$vlan"; then
				echo "invalid $type/$vlan combination"
				rc=7
			fi
		else
			echo "Must specify the vlan id"
			rc=6
		fi
	else
		echo "Need to know if the vlan is public or private."
		rc=5
	fi

	if [[ $rc != 0 ]]; then
		echo "Valid vlans:"
		ibmcloud cs vlans --zone "$location"
	fi

	return $rc
}

cloud_is_hardware_valid() {
	local rc=0
	local -r hardware="${1}"; shift

	if [[ $hardware != "shared" && $hardware != "dedicated" ]]; then
		echo "Specify if shared or dedicated hardware should be used."
		echo "shared"
		echo "dedicated"
		rc=8
	fi

	return $rc
}

cloud_is_org_valid() {
	local rc=0
	local org="${1}"; shift

	if [[ $org != "" ]]; then
		if ! ibmcloud iam orgs | grep -q "$org"; then
			echo "The organization $org is not recongized"
			rc=9
		fi
	fi

	if [[ $rc != 0 ]]; then
		echo "Valid organizations:"
		ibmcloud iam orgs
	fi

	return $rc
}

cloud_is_space_valid() {
	local rc=0
	local space="${1}"; shift

	if [[ $space != "" ]]; then
		if ! ibmcloud iam spaces | grep -q "$space"; then
			echo "The space $space is not recognized"
			rc=10
		fi
	fi

	if [[ $rc != 0 ]]; then
		echo "Valid spaces:"
		ibmcloud iam spaces
	fi

	return $rc
}

