#!/usr/bin/env bash
#
# Licensed Materials - Property of IBM
#
# IBM Financial Crimes Insight with Watson PID 5900-A0H
# IBM Financial Crimes Insight with Watson, Private PID 5737-E41
#
# (C) Copyright IBM Corp. 2017, 2018, 2019  All rights reserved.
#
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U. S. Copyright Office.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#

convert-seconds() {
        local hours minutes seconds

        (( hours   = ${1}/3600 ))
        (( minutes = (${1}%3600)/60 ))
        (( seconds = ${1}%60 ))

        echo "$hours hours $minutes minutes $seconds seconds elapsed time]"
}

wait-for-matching-output() {
	local -r max_time="$1"; shift
	local -r message="$1"; shift
	local -r cmd="$1"; shift
	local -r expected="$1"; shift
	local delay_block_size=15 delay_block=0 last_delay_block=0
	local start_time=$(date +%s) end_time
	local elapsed_time

	echo -n "Waiting up to $max_time seconds for $message:  "

	actual=$(eval "$cmd") || {
		echo;
		echo "Failed to execute command:  $cmd";
		return 1;
	}
	while [[ "$actual" != "$expected" ]]; do
		sleep 1
		end_time=$(date +%s)
		delay_block=$(( (end_time - start_time) / delay_block_size ))

		if [[ $delay_block != $last_delay_block ]]; then
			echo -n "."
			last_delay_block=$delay_block
		fi

		if [[ $((end_time-start_time)) -gt $max_time ]]; then
			elapsed_time=$(convert-seconds $((end_time-start_time)) )
			echo "Timed out $elapsed_time"
			return 1
		fi

		actual=$(eval "$cmd") || {
			echo;
			echo "Failed to execute command:  $cmd";
			return 1;
		}
	done
	end_time=$(date +%s)

	# shellcheck disable=SC2034
	elapsed_time=$(convert-seconds $((end_time-start_time)) )
	echo "OK $elapsed_time"

	return 0
}
